copy_basisu_memory_to_host

Function copy_basisu_memory_to_host 

pub unsafe fn copy_basisu_memory_to_host(basisu_ptr: u64, count: u64) -> Vec<u8> 
Use this to copy memory between host and basisu. This is required on web where memory isn’t shared.

Safety

basisu_ptr must be valid pointer allocated by bu_alloc or bt_alloc and must be valid for reads of count bytes.