copy_host_memory_to_basisu

Function copy_host_memory_to_basisu 

pub unsafe fn copy_host_memory_to_basisu(data: &[u8], basisu_ptr: u64)
Use this to copy memory between host and basisu. This is required on web where memory isn’t shared.

Safety

basisu_ptr must be valid pointer allocated by bu_alloc or bt_alloc and must be valid for writes of data.len() bytes.