pub async fn instantiate_custom_basisu_wasm(wasm_data: &[u8])Available on
target_os=unknown and target_vendor=unknown and WebAssembly only.Expand description
Instantiate the you custom basisu wasm, required on web before calling other functions. The wasm must be compatible with basisu C API.
Once instantiate_basisu_wasm/instantiate_custom_basisu_wasm is called, the wasm can’t be changed.